Post
Martin Bonnin
mbonnin.net
did:plc:i5mxz4yzao5nnmx76cxouvok
Somewhat of a side note but enabling CC seems to have quite the overhead since I go from ~6s to ~2s if I just add `--no-configuration-cache`.
That's on a CC miss of course but depending the patterns CC might not always be an improvement π€
2025-11-04T14:29:00.356Z